#!/bin/bash
#
# Source : http://www.linuxvirtualserver.org/software/kernel-2.6/ipvsadm-1.25.tar.gz
# Maintainer : Son|c <emmanuel.bailleul@cegetel.net>
#


#------------------( Set Package Variables )


soft='ipvsadm'
softversion='1.25'
packageversion='62.1'


#------------------( Set Architecture Variables )

arch='i486'
cpu='i686'


#------------------( Set Architecture Variables )


buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"


#------------------( Prepare The Work Area And Source Package )


cd $buildir
rm -f {$dest,$dest.dep,$dest.md5,$dest.tgz,$package,$package.md5,$src} 1>/dev/null 2>&1
tar -xvzf $srcpkg
mkdir -p $dest


#------------------( Set Build Ownerships, Permissions and CFLAGS )


    chown -R root:root . 
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu" 
export CXXFLAGS="$CFLAGS"

#------------------( Make and Install Software )

cd $src
make

mkdir -p $dest/usr/sbin
mkdir -p $dest/usr/man/man8

cp ipvsadm $dest/usr/sbin
cp ipvsadm.8 $dest/usr/man/man8

#------------------ Strip Executables (Comment out these lines if debugging info is needed) )

cd $dest
chown -R root:root $dest
( cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#
# add 'default' files
#
mkdir -p $dest/usr/doc/$soft-$softversion
cd $src
cp -a README VERSION TAGS SCHEDULERS $dest/usr/doc/$soft-$softversion

#------------------( Copy Build The Script )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( Create and Install The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc 
    |-----handy-ruler------------------------------------------------------|
ipvsadm: LVS admin tool
ipvsadm:
ipvsadm: ipvsadm is a utility to administer the IP virtual server services
ipvsadm: offered by the Linux kernel with IP virtual server support.
ipvsadm: 
ipvsadm: 
ipvsadm:
ipvsadm:
ipvsadm:
ipvsadm:
EOF


#------------------( Compress Man Pages )

( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)


#------------------( Create The *.dep File )


cd $dest
depfinder $dest > $buildir/$package.dep

#------------------( Compress The Package And Clean Up The Work Area )


cd $dest
makepkg -l y -c n $dest.txz
rm -rf $src
rm -rf $dest


#------------------( Generate the MD5 Check Sum )


cd $buildir
rm -f $package.md5
md5sum $package.txz > $package.md5

# Create source file
echo "http://www.linuxvirtualserver.org/software/kernel-2.6/ipvsadm-1.25.tar.gz" > $package.src
echo "http://download.zenwalk.org/people/emmanuel/$soft-$softversion/build-$soft.sh" >> $package.src
